==> jc-tke-client-1.0.322-sources.jar: com/xforceplus/ultraman/app/jctke/controller/PurchaseOrderFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * 采购订单主信息feign客户端
 *
 * @author ultraman
 * @date 2022-05-12
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.PurchaseOrder;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface PurchaseOrderFeignApi {

  /**
   * 通过id查询采购订单主信息
   * @param  id
   * @return R
   */
  @GetMapping("/purchaseOrder/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增采购订单主信息
   * @param purchaseOrder 采购订单主信息
   * @return R
   */
  @PostMapping("/purchaseOrder/add")
  public R save(@RequestBody PurchaseOrder purchaseOrder);

  /**
   * 修改采购订单主信息
   * @param purchaseOrder 采购订单主信息
   * @return R
   */
  @PostMapping("/purchaseOrder/update")
  public R updateById(@RequestBody PurchaseOrder purchaseOrder);

  /**
   * 通过id删除采购订单主信息
   * @param  id
   * @return R
   */
  @DeleteMapping("/purchaseOrder/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-tke-client-1.0.351-sources.jar: com/xforceplus/ultraman/app/jctke/controller/PurchaseOrderFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * feign客户端
 *
 * @author ultraman
 * @date 2022-05-14
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.PurchaseOrder;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface PurchaseOrderFeignApi {

  /**
   * 通过id查询
   * @param  id
   * @return R
   */
  @GetMapping("/purchaseOrder/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增
   * @param purchaseOrder 
   * @return R
   */
  @PostMapping("/purchaseOrder/add")
  public R save(@RequestBody PurchaseOrder purchaseOrder);

  /**
   * 修改
   * @param purchaseOrder 
   * @return R
   */
  @PostMapping("/purchaseOrder/update")
  public R updateById(@RequestBody PurchaseOrder purchaseOrder);

  /**
   * 通过id删除
   * @param  id
   * @return R
   */
  @DeleteMapping("/purchaseOrder/del/{id}" )
  public R removeById(@PathVariable Long id);

}
